![composipy Logo](docs/static/composipy_logo.PNG)

# Overview

**composipy** is a python library to calculate composite plates using the classical laminate theory. This library is designed to be simple, userfriendly and helpfull.

This library is for learning purposes. 


## Download using PYPI
```shell
pip install composipy
```

Access the PYPI project:

https://pypi.org/project/composipy/

## Documentation

- [Getting Started](https://rafaelpsilva07.github.io/composipydocs/userGuide/getting_start.html)
- [Examples Notebooks](https://rafaelpsilva07.github.io/composipydocs/examples/index.html)
- [Code Documentation](https://rafaelpsilva07.github.io/composipydocs/reference/index.html)

## Whats new in composipy?

### 0.3.1
- Class Load added
- Class Strength added, wich allows the user calculate stresses and check failure criterias of a composite
- Documentation was updated with jupyter notebook examples

### 0.2.0
 - composipy is simpler and more robust!
 - Documentation added.
 - Validation tests added.
 - Rayleigh Ritz method for buckling calculation has been removed for simplification purposes. But it can be founded in realease 0.1.3.
 
## Roadmap
- Theoretical manual
- Failure criteria functions
- Mechanical calculations utils
- Jupyter notebooks with exploratory examples